==> jc-1.4.0.tar.gz: soot/toolkits/scalar/ForwardFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.ForwardFlowAnalysis

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_FlowAnalysis

#include "soot/toolkits/scalar/FlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_ForwardFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_ForwardFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method$doAnalysis$aa9bebddf0f94464(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *);
extern jboolean _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method$isForward$48ad1d1fce741d09(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method_info$doAnalysis$aa9bebddf0f94464;
extern _jc_method _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method_info$isForward$48ad1d1fce741d09;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods {
	void	(*doAnalysis$aa9bebddf0f94464)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *);
	jboolean	(*isForward$48ad1d1fce741d09)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *);
};

// Vtable
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object {
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype _jc_soot_toolkits_scalar_ForwardFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ForwardFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ForwardFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_ForwardFlowAnalysis_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/scalar/ForwardFlowAnalysis.h <==
// public abstract class soot.toolkits.scalar.ForwardFlowAnalysis

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 36c7c662bc399f02 soot_toolkits_scalar_AbstractFlowAnalysis
// @dep_class d57b0cae040f1388 soot_toolkits_scalar_FlowAnalysis
// @dep_class 670b274dd70b8d71 soot_toolkits_scalar_ForwardFlowAnalysis

// header file dependencies
// @dep_header soot_toolkits_scalar_FlowAnalysis

#include "soot/toolkits/scalar/FlowAnalysis.h"

#ifndef _JC_soot_toolkits_scalar_ForwardFlowAnalysis_H_
#define _JC_soot_toolkits_scalar_ForwardFlowAnalysis_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_DirectedGraph$object;

// Typedefs
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs;
typedef struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$object;

typedef const struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods;
typedef const struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable;
typedef const struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype;

// Constructors
extern void _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method$_init$ac2601640312c3c2(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method$doAnalysis$aa9bebddf0f94464(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method$isForward$48ad1d1fce741d09(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method_info$doAnalysis$aa9bebddf0f94464;
extern _jc_method _jc_soot_toolkits_scalar_ForwardFlowAnalysis$method_info$isForward$48ad1d1fce741d09;

// Virtual methods structure
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods {
	void	(*doAnalysis$aa9bebddf0f94464)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *) _JC_JCNI_ATTR;
	jboolean	(*isForward$48ad1d1fce741d09)(_jc_env *, struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_scalar_AbstractFlowAnalysis$vmethods	soot_toolkits_scalar_AbstractFlowAnalysis;
	_jc_soot_toolkits_scalar_FlowAnalysis$vmethods	soot_toolkits_scalar_FlowAnalysis;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vmethods	soot_toolkits_scalar_ForwardFlowAnalysis;
};

// Vtype
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype {
	_jc_type			type;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs {
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_refs	soot_toolkits_scalar_ForwardFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_refs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_refs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_scalar_AbstractFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_AbstractFlowAnalysis;
    _jc_soot_toolkits_scalar_FlowAnalysis$sub_nonrefs	soot_toolkits_scalar_FlowAnalysis;
    _jc_soot_toolkits_scalar_ForwardFlowAnalysis$sub_nonrefs	soot_toolkits_scalar_ForwardFlowAnalysis;
};

// Object instance structure
struct _jc_soot_toolkits_scalar_ForwardFlowAnalysis$object {
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype	*vtype;
	_jc_soot_toolkits_scalar_ForwardFlowAnalysis$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_scalar_ForwardFlowAnalysis$vtype _jc_soot_toolkits_scalar_ForwardFlowAnalysis$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_scalar_ForwardFlowAnalysis, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_scalar_ForwardFlowAnalysis$class_object;

#endif	/* _JC_soot_toolkits_scalar_ForwardFlowAnalysis_H_ */
